@@ -174,7 +174,7 @@ where
     fn pick_lru(&mut self, choices: &mut Vec<String>) -> String {
         for (index, choice) in choices.iter().enumerate() {
             if self.ui.call_display_table() {
-                self.display_lru_table(index, &choices);
+                self.display_lru_table(index, choices);
             }
 
             if self.get_consent(&choice[..]) {
@@ -434,8 +434,8 @@ mod tests {
             .returning(|x| !x.contains("don't"));
         let mut engine = Engine::new(&ui);
 
-        assert_eq!(engine.get_consent("you want this"), true);
-        assert_eq!(engine.get_consent("you don't want this"), false);
+        assert!(engine.get_consent("you want this"));
+        assert!(!engine.get_consent("you don't want this"));
     }
 
     #[test]
